@@ -32,7 +32,7 @@ TcpConnectWidget::TcpConnectWidget(QWidget *parent) : QWidget(parent), Ui::TcpCo
   qCDebug(KSIRK_LOG) << "";
   setupUi(this);
   QRegExp rx(".+");
-  QRegExpValidator *v = new QRegExpValidator(rx, 0);
+  QRegExpValidator *v = new QRegExpValidator(rx, this);
   hostEdit->setValidator(v);
 
   connect(nextButton,SIGNAL(clicked(bool)),this,SIGNAL(next()));
